#!/usr/bin/env python3

from pycookiecheat import chrome_cookies
from http import cookies
import subprocess
import sys

def main():
    if len(sys.argv) < 2:
        print("usage: curlc [url] <curl args...>")
        sys.exit(1)

    curlargs = sys.argv[1:]
    for arg in curlargs:
        if arg[0] != '-':
            url = arg
            break

    chrome = chrome_cookies(url)
    C = cookies.SimpleCookie()

    for k, v in chrome.items():
        C[k] = v

    curlstr = str(C)
    args = ["curl", "-H", curlstr]
    args.extend(curlargs)
    subprocess.run(args)


if __name__ == '__main__':
    main()



from setuptools import setup

version = '0.0.1'

setup(
    name='curlc',
    version=version,
    packages = ['curlc'],
    description="curl wrapper to borrow cookies from your browser's authenticated session",
    author='William Casarin',
    author_email='bill@casarin.me',
    url='https://github.com/jb55/curlc',
    include_package_data=True,
    install_requires=[ "pycookiecheat >= 0.2.0" ],
    entry_points = {'console_scripts': ['curlc = curlc:main'] },
    license="GPLv2",
    keywords='curlc',
    classifiers=[
      'Programming Language :: Python :: 3',
      'Environment :: Console',
      'Intended Audience :: Developers',
      'Intended Audience :: System Administrators',
      'Topic :: Internet :: WWW/HTTP',
      'Topic :: Software Development',
      'Topic :: System :: Networking',
      'Topic :: Terminals',
      'Topic :: Utilities'
    ],
)
